emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/realgud-ipdb ee61067 3/6: Administrivia ...


From: Rocky Bernstein
Subject: [elpa] externals/realgud-ipdb ee61067 3/6: Administrivia ...
Date: Thu, 23 May 2019 02:10:11 -0400 (EDT)

branch: externals/realgud-ipdb
commit ee6106773a9dd5e700996cd100069d0736d4e1df
Author: rocky <address@hidden>
Commit: rocky <address@hidden>

    Administrivia ...
    
    * Require Emacs 25.1 or greater.
    * Track elc dependencies
---
 compute-lispdir.sh | 46 ++++++++++++++++++++++++++++++++++++++++++++++
 ipdb/Makefile.am   |  5 ++++-
 ipdb/ipdb.el       |  2 +-
 realgud-ipdb.el    |  4 ++--
 4 files changed, 53 insertions(+), 4 deletions(-)

diff --git a/compute-lispdir.sh b/compute-lispdir.sh
new file mode 100755
index 0000000..553b579
--- /dev/null
+++ b/compute-lispdir.sh
@@ -0,0 +1,46 @@
+#!/bin/bash
+# Figures out a reasonable --prefix
+typeset -i rc=0
+typeset -i DEBUG=${DEBUG:-0}
+EMACS_PROG=${EMACS_PROG:-emacs}
+list=$($EMACS_PROG --batch --no-splash --no-site-file --eval '(message 
(substring (format "%s" load-path) 1 -1))' 2>&1)
+rc=$?
+if (( rc != 0 )) ; then
+    echo  >&2 "Something went wrong running $EMACS_PROG"
+    exit $rc
+$cmd
+fi
+for dir in $list ; do
+    if [[ -d $dir ]] ; then
+       case $dir in
+           */emacs/site-lisp)
+               ((DEBUG)) && echo "site lisp: $dir"
+               echo "$dir"
+               exit 0
+               ;;
+       esac
+    fi
+done
+for dir in $list ; do
+    if [[ -d $dir ]] ; then
+       case $dir in
+           */emacs/2[5-8]\.[0-9]/site-lisp)
+               ((DEBUG)) && echo "versioned site lisp: $dir"
+               echo "$dir"
+               exit 0
+               ;;
+       esac
+    fi
+done
+for dir in $list ; do
+    if [[ -d $dir ]] ; then
+       case $dir in
+           */emacs/2[5-8]\.[0-9]/site-lisp)
+               ((DEBUG)) && echo "versioned site lisp: $dir"
+               echo "$dir"
+               exit 0
+               ;;
+       esac
+    fi
+done
+exit 0
diff --git a/ipdb/Makefile.am b/ipdb/Makefile.am
index e8453c0..b15e3bf 100644
--- a/ipdb/Makefile.am
+++ b/ipdb/Makefile.am
@@ -2,4 +2,7 @@ lisp_files = $(wildcard *.el)
 EXTRA_DIST=$(lisp_files)
 lisp_LISP = $(lisp_files)
 include ../common.mk
-lispdir = @lispdir@/lldb
+lispdir = @lispdir@/ipdb
+
+ipdb.elc: core.elc track-mode.elc
+track-mode.elc: core.elc init.elc
diff --git a/ipdb/ipdb.el b/ipdb/ipdb.el
index 4e5d0f7..77f5e11 100644
--- a/ipdb/ipdb.el
+++ b/ipdb/ipdb.el
@@ -27,7 +27,7 @@
 (defgroup realgud:ipdb nil
   "The realgud interface to the Python ipdb debugger"
   :group 'realgud
-  :version "24.3")
+  :version "25.1")
 
 (declare-function make-realgud-loc "realgud-loc" (a b c d e f))
 
diff --git a/realgud-ipdb.el b/realgud-ipdb.el
index 5a4c1e9..a5be7e8 100644
--- a/realgud-ipdb.el
+++ b/realgud-ipdb.el
@@ -4,7 +4,7 @@
 ;; Version: 1.0.0
 ;; Package-Requires: ((realgud "1.4.5") (load-relative "1.2") (cl-lib "0.5") 
(emacs "24"))
 ;; URL: http://github.com/rocky/realgud-ipdb
 ;; Compatibility: GNU Emacs 24.x
 
 ;; Copyright (C) 2019 Free Software Foundation, Inc
 
@@ -38,7 +38,7 @@
 (defgroup realgud-ipdb  nil
   "Realgud interface to ipdb"
   :group 'realgud
-  :version "24.3")
+  :version "25.1")
 
 (require-relative-list '( "./ipdb/ipdb" ) "realgud-")
 
@@ -4,7 +4,7 @@
(emacs "24"))
 ;; URL: http://github.com/rocky/realgud-ipdb
-;; Compatibility: GNU Emacs 24.x
+;; Compatibility: GNU Emacs 25.x
 
 ;; Copyright (C) 2019 Free Software Foundation, Inc



reply via email to

[Prev in Thread] Current Thread [Next in Thread]